@@ -1,7 +1,7 @@
 // Filename: emulator.rs
 // Author:	 Kai Rese
-// Version:	 0.4
-// Date:	 14-11-2021 (DD-MM-YYYY)
+// Version:	 0.6
+// Date:	 15-01-2022 (DD-MM-YYYY)
 // Library:  gpcas_arschitek_zero
 //
 // Copyright (c) 2021 Kai Rese
@@ -172,7 +172,7 @@ impl Emulator for ArschitekZeroEmulator {
                     instruction.inputs[0] = template_data.reg0;
                     instruction.inputs[1] = template_data.reg1;
                     instruction.memory_address = (self.registers[template_data.reg1 as usize]
-                        .wrapping_add(sign_extend_u4(template_data.reg2_imm4) << 1)
+                        .wrapping_add(sign_extend_u4(template_data.reg2_imm4))
                         as usize)
                         << 1;
                     if commit {
@@ -425,15 +425,15 @@ const BASE_VALUES: [InstructionBaseValues; 16] = [
     },
     // 2: Jump IP-relative
     InstructionBaseValues {
-        instr_type: instruction_type::JUMP,
-        flags: instruction_flags::IS_BR | instruction_flags::BR_TAKEN,
+        instr_type: instruction_type::BRANCH,
+        flags: instruction_flags::BR_TYPE_JUMP,
         input_register_count: 0,
         memory_register_count: 0,
     },
     // 3: Branch equal zero
     InstructionBaseValues {
         instr_type: instruction_type::BRANCH,
-        flags: instruction_flags::IS_BR,
+        flags: instruction_flags::BR_TYPE_CONDITIONAL,
         input_register_count: 1,
         memory_register_count: 0,
     },
@@ -454,14 +454,14 @@ const BASE_VALUES: [InstructionBaseValues; 16] = [
     // 6: Jump base + offset
     InstructionBaseValues {
         instr_type: instruction_type::BRANCH,
-        flags: instruction_flags::IS_BR | instruction_flags::BR_TAKEN,
+        flags: instruction_flags::BR_TYPE_JUMP | instruction_flags::BR_INDIRECT,
         input_register_count: 1,
         memory_register_count: 0,
     },
     // 7: Branch negative
     InstructionBaseValues {
         instr_type: instruction_type::BRANCH,
-        flags: instruction_flags::IS_BR,
+        flags: instruction_flags::BR_TYPE_CONDITIONAL,
         input_register_count: 1,
         memory_register_count: 0,
     },
